package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.constants.StatusConstant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaMateTagService;
import com.shigongli.entity.TaMateTag;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 素材标签 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "素材标签")
@RestController
@RequestMapping("/")
public class TaMateTagController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMateTagController.class);

    @Autowired
    public ITaMateTagService iTaMateTagService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/mp/taMateTag",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMateTagList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaMateTag> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaMateTag> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaMateTag> result = iTaMateTagService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taMateTag 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taMateTag",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taMateTagAdd(@ApiParam("保存内容") @RequestBody TaMateTag taMateTag) throws Exception{

        if (iTaMateTagService.save(taMateTag)){
            return ResponseBean.success(taMateTag);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taMateTag/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taMateTagDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaMateTag taMateTag = iTaMateTagService.getById(id);
        if (null == taMateTag || taMateTag.getStatus().equals(StatusConstant.DELETE)) {
            return ResponseBean.success("ok");
        }
        taMateTag.setStatus(StatusConstant.DELETE);
        return taMateTagUpdate(id, taMateTag);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMateTag 实体对象
     * @return
     */
    @RequestMapping(value="/mp/taMateTag/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taMateTagUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaMateTag taMateTag) throws Exception{

        if (iTaMateTagService.updateById(taMateTag)){
            return ResponseBean.success(iTaMateTagService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/mp/taMateTag/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMateTagGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        return ResponseBean.success(iTaMateTagService.getById(id));
    }
}
