package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaMetaImageTagService;
import com.shigongli.entity.TaMetaImageTag;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
    * 图片标签 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "图片标签")
@RestController
@RequestMapping("/")
public class TaMetaImageTagController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMetaImageTagController.class);

    @Autowired
    public ITaMetaImageTagService iTaMetaImageTagService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taMetaImageTag",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMetaImageTagList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                           @ApiParam("标签ID") @RequestParam(value ="tagId") String tagId) throws Exception{

		    IPage<TaMetaImageTag> pg = new Page<>(pageNum, pageSize);

            IPage<TaMetaImageTag> result = iTaMetaImageTagService.pagedBy(pg, tagId);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taMetaImageTag 实体对象
     * @return
     */
    @RequestMapping(value="/taMetaImageTag",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taMetaImageTagAdd(@ApiParam("保存内容") @RequestBody List<Map<String, String>> datas) throws Exception{
        List<String> tagIds = new ArrayList<>();
        List<TaMetaImageTag> taMetaImageTags = new ArrayList<>();

        for (Map<String, String> item: datas) {
            String tagId = item.get("tagId");
            String imageId = item.get("imageId");

            TaMetaImageTag taMetaImageTag = new TaMetaImageTag();
            taMetaImageTag.setImageId(imageId);
            taMetaImageTag.setTagId(tagId);
            taMetaImageTags.add(taMetaImageTag);

            if (!tagIds.contains(tagId)) {
                tagIds.add(tagId);
            }
        }

        // 先清除所有数据
        iTaMetaImageTagService.removeAllBy(tagIds);

        // 再保存所有
        iTaMetaImageTagService.saveBatch(taMetaImageTags);

        return ResponseBean.success("ok");
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taMetaImageTag/{id}", method= RequestMethod.DELETE)
//    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
//    public ResponseBean taMetaImageTagDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        if(iTaMetaImageTagService.removeById(id)){
//            return ResponseBean.success("success");
//        }else {
//            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taMetaImageTag 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taMetaImageTag/{id}",method= RequestMethod.PUT)
//    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
//    public ResponseBean taMetaImageTagUpdate(@ApiParam("对象ID") @PathVariable Integer id,
//                                        @ApiParam("更新内容") @RequestBody TaMetaImageTag taMetaImageTag) throws Exception{
//
//        if (iTaMetaImageTagService.updateById(taMetaImageTag)){
//            return ResponseBean.success(iTaMetaImageTagService.getById(id));
//        }else {
//            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
//        }
//    }
//
//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taMetaImageTag/{id}",method= RequestMethod.GET)
//    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
//    public ResponseBean taMetaImageTagGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
//        return ResponseBean.success(iTaMetaImageTagService.getById(id));
//    }
}
